@@ -2,7 +2,7 @@ package Plack::Request;
 use strict;
 use warnings;
 use 5.008_001;
-our $VERSION = "0.02";
+our $VERSION = "0.03";
 
 use HTTP::Headers;
 use URI::QueryParam;
@@ -356,8 +356,8 @@ sub _build_uri  {
 
     my $uri = ($env->{'psgi.url_scheme'} || "http") .
         "://" .
-        ($env->{HTTP_HOST} || $env->{SERVER_NAME} || "") .
-        ":" . ($env->{SERVER_PORT} || 80) . "/" .
+        ($env->{HTTP_HOST} || ($env->{SERVER_NAME} || "") . ":" . ($env->{SERVER_PORT} || 80)) .
+        "/" .
         ($path || "") .
         ($env->{QUERY_STRING} ? "?$env->{QUERY_STRING}" : "");
 
